@@ -4,6 +4,9 @@
 
 #ifdef __hpux
     #define DEFAULT_MAIL_COMMAND "/usr/bin/mailx -s"
+    #define COMPRESS_COMMAND "/usr/contrib/bin/gzip"
+    #define UNCOMPRESS_COMMAND " /usr/contrib/bin/gunzip"
+    #define STATEFILE "/var/run/logrotate.status"
 #endif
 
 
